@@ -201,9 +201,6 @@ GError*  gconf_compose_errors (GError* err1, GError* err2);
 #else
 /* Stubs that do something close enough.  */
 #    define textdomain(String) (String)
-#    define gettext(String) (String)
-#    define dgettext(Domain,Message) (Message)
-#    define dcgettext(Domain,Message,Type) (Message)
 #    define bindtextdomain(Domain,Directory) (Domain)
 #    define _(String) (String)
 #    define N_(String) (String)
